# afivmax

[![Build Status](https://travis-ci.com/eggachecat/afivmax.svg?branch=master)](https://travis-ci.com/eggachecat/afivmax)
[![PyPI version](https://badge.fury.io/py/afivmax.svg)](https://badge.fury.io/py/afivmax)
[![Coverage Status](https://coveralls.io/repos/github/eggachecat/afivmax/badge.svg?branch=master)](https://coveralls.io/github/eggachecat/afivmax?branch=master)